# local-logger-python-backend

Please add to \requirements.txt
local-logger-python-backend==0.0.1

Please includ at least two Logger calls in each method:
"Start " + class.method names "( "+ parameters + ")";
"Start " + class.method names + " returned " + return values;
